@@ -1,19 +1,25 @@
-from typing import List, Optional, Dict, Union, Tuple, Callable
+from typing import Callable, Dict, List, Optional, Tuple, Union
 
-import pandas as pd
 import numpy as np
-import dash
-import dash_html_components as html
-from dash.dependencies import Input, Output
+import pandas as pd
 import webviz_core_components as wcc
+from dash import Dash, Input, Output, html
+from webviz_config import WebvizPluginABC, WebvizSettings
 from webviz_config.common_cache import CACHE
-from webviz_config import WebvizPluginABC
-from webviz_config import WebvizSettings
 
-from webviz_subsurface._models import EnsembleSetModel
-from webviz_subsurface._models import caching_ensemble_set_model_factory
+from webviz_subsurface._models import (
+    EnsembleSetModel,
+    caching_ensemble_set_model_factory,
+)
+
+from .._utils.fanchart_plotting import (
+    FanchartData,
+    FreeLineData,
+    LowHighData,
+    MinMaxData,
+    get_fanchart_traces,
+)
 from .._utils.unique_theming import unique_colors
-from .._utils.colors import hex_to_rgba
 
 
 class BhpQc(WebvizPluginABC):
@@ -37,7 +43,7 @@ class BhpQc(WebvizPluginABC):
 
     def __init__(
         self,
-        app: dash.Dash,
+        app: Dash,
         webviz_settings: WebvizSettings,
         ensembles: list,
         wells: Optional[List[str]] = None,
@@ -207,7 +213,7 @@ class BhpQc(WebvizPluginABC):
             ],
         )
 
-    def set_callbacks(self, app: dash.Dash) -> None:
+    def set_callbacks(self, app: Dash) -> None:
         @app.callback(
             Output(self.uuid("graph"), "figure"),
             Input(self.uuid("ensemble"), "value"),
@@ -238,7 +244,7 @@ class BhpQc(WebvizPluginABC):
             traces = []
             if plot_type == "Fan chart":
                 traces.extend(
-                    add_fanchart_traces(
+                    _get_fanchart_traces(
                         ens_stat_df=stat_df,
                         color=self.ens_colors[ensemble],
                         legend_group=ensemble,
@@ -364,74 +370,33 @@ def calc_statistics(df: pd.DataFrame) -> pd.DataFrame:
     return stat_df
 
 
-def add_fanchart_traces(
+def _get_fanchart_traces(
     ens_stat_df: pd.DataFrame,
     color: str,
     legend_group: str,
 ) -> List[dict]:
     """Renders a fanchart for an ensemble vector"""
 
-    fill_color = hex_to_rgba(color, 0.3)
-    line_color = hex_to_rgba(color, 1)
     x = [vec[5:] for vec in ens_stat_df.index]
 
-    return [
-        {
-            "name": legend_group,
-            "hovertext": "Maximum",
-            "x": x,
-            "y": ens_stat_df["max"],
-            "mode": "lines",
-            "line": {"width": 0, "color": line_color},
-            "legendgroup": legend_group,
-            "showlegend": False,
-        },
-        {
-            "name": legend_group,
-            "hovertext": "P90 (low)",
-            "x": x,
-            "y": ens_stat_df["low_p90"],
-            "mode": "lines",
-            "fill": "tonexty",
-            "fillcolor": fill_color,
-            "line": {"width": 0, "color": line_color},
-            "legendgroup": legend_group,
-            "showlegend": False,
-        },
-        {
-            "name": legend_group,
-            "hovertext": "P10 (high)",
-            "x": x,
-            "y": ens_stat_df["high_p10"],
-            "mode": "lines",
-            "fill": "tonexty",
-            "fillcolor": fill_color,
-            "line": {"width": 0, "color": line_color},
-            "legendgroup": legend_group,
-            "showlegend": False,
-        },
-        {
-            "name": legend_group,
-            "hovertext": "Mean",
-            "x": x,
-            "y": ens_stat_df["mean"],
-            "mode": "lines",
-            "fill": "tonexty",
-            "fillcolor": fill_color,
-            "line": {"color": line_color},
-            "legendgroup": legend_group,
-            "showlegend": True,
-        },
-        {
-            "name": legend_group,
-            "hovertext": "Minimum",
-            "x": x,
-            "y": ens_stat_df["min"],
-            "mode": "lines",
-            "fill": "tonexty",
-            "fillcolor": fill_color,
-            "line": {"width": 0, "color": line_color},
-            "legendgroup": legend_group,
-            "showlegend": False,
-        },
-    ]
+    data = FanchartData(
+        samples=x,
+        low_high=LowHighData(
+            low_data=ens_stat_df["low_p90"].values,
+            low_name="P90 (low)",
+            high_data=ens_stat_df["high_p10"].values,
+            high_name="P10 (high)",
+        ),
+        minimum_maximum=MinMaxData(
+            minimum=ens_stat_df["min"].values,
+            maximum=ens_stat_df["max"].values,
+        ),
+        free_line=FreeLineData("Mean", ens_stat_df["mean"].values),
+    )
+
+    return get_fanchart_traces(
+        data=data,
+        hex_color=color,
+        legend_group=legend_group,
+        hovermode="x",
+    )
