@@ -1,23 +1,21 @@
-from typing import Dict, List, Tuple, Callable
 from pathlib import Path
+from typing import Callable, Dict, List, Tuple
 
 import pandas as pd
-import dash
-import dash_html_components as html
-
-from webviz_config.webviz_store import webvizstore
-from webviz_config import WebvizPluginABC
-from webviz_config import WebvizSettings
-from webviz_config.webviz_assets import WEBVIZ_ASSETS
 import webviz_core_components as wcc
+from dash import Dash, html
+from webviz_config import WebvizPluginABC, WebvizSettings
+from webviz_config.webviz_assets import WEBVIZ_ASSETS
+from webviz_config.webviz_store import webvizstore
 
-from webviz_subsurface._utils.unique_theming import unique_colors
+import webviz_subsurface
+from webviz_subsurface._components.parameter_filter import ParameterFilter
 from webviz_subsurface._models import ObservationModel
 from webviz_subsurface._providers import EnsembleTableProviderFactory
-from webviz_subsurface._components.parameter_filter import ParameterFilter
-import webviz_subsurface
-from .views import main_view
+from webviz_subsurface._utils.unique_theming import unique_colors
+
 from .controllers import build_figure, update_figure_clientside
+from .views import main_view
 
 
 class LinePlotterFMU(WebvizPluginABC):
@@ -38,7 +36,7 @@ class LinePlotterFMU(WebvizPluginABC):
     # pylint: disable=too-many-locals, too-many-arguments
     def __init__(
         self,
-        app: dash.Dash,
+        app: Dash,
         webviz_settings: WebvizSettings,
         csvfile: str = None,
         ensembles: list = None,
@@ -112,7 +110,7 @@ class LinePlotterFMU(WebvizPluginABC):
         parameterdf = pd.concat(dfs)
         self._realizations = sorted(list(parameterdf["REAL"].unique()))
         self._parameter_filter = ParameterFilter(
-            app, self.uuid("parameter-filter"), parameterdf
+            self.uuid("parameter-filter"), parameterdf
         )
         self._observationfile = observation_file
         self._observationmodel = (
@@ -168,7 +166,7 @@ class LinePlotterFMU(WebvizPluginABC):
             ]
         )
 
-    def set_callbacks(self, app: dash.Dash) -> None:
+    def set_callbacks(self, app: Dash) -> None:
         build_figure(
             app,
             get_uuid=self.uuid,
